@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Bencher::Scenario;
 
-our $DATE = '2016-07-13'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-07-17'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -95,7 +95,7 @@ sub _gen_chart {
                     $table_num, $output_file]);
     }
 
-    push @$pod, "#IMAGE: $build_file\n\n";
+    push @$pod, "#IMAGE: $build_file|$output_file\n\n";
 
     # this is very very dirty. we mark that we have created some chart files in
     # a temp dir, so Dist::Zilla::Plugin::Bencher::Scenario can add them to the
@@ -121,7 +121,7 @@ sub _process_module {
         require $package_pm;
     }
 
-    my $tempdir = File::Temp::tempdir(CLEANUP=>0);
+    my $tempdir = File::Temp::tempdir(CLEANUP=>1);
 
     my $scenario = Bencher::Backend::parse_scenario(
         scenario => ${"$package\::scenario"});
@@ -432,7 +432,7 @@ Pod::Weaver::Plugin::Bencher::Scenario - Plugin to use when building Bencher::Sc
 
 =head1 VERSION
 
-This document describes version 0.18 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-07-13.
+This document describes version 0.19 of Pod::Weaver::Plugin::Bencher::Scenario (from Perl distribution Pod-Weaver-Plugin-Bencher-Scenario), released on 2016-07-17.
 
 =head1 SYNOPSIS
 
